NenuCAL CD
==========

Calibration pipeline for the NenuFAR Cosmic Dawn project

Installation
------------

nenucal-cd can be installed via pip:

    $ pip install nenucal-cd

and requires Python 3.7.0 or higher. For most tasks, you will also need [DPPP](https://github.com/lofar-astron/DP3/tree/master/DPPP), [LSMTool](https://www.astron.nl/citt/lsmtool/overview.html) that you can install with the command:

    $ pip install git+https://github.com/darafferty/LSMTool.git

and [LoSoTo](https://revoltek.github.io/losoto/) that you can install with the command:

    $ pip install git+https://github.com/revoltek/losoto

